@@ -3,9 +3,9 @@ import glob
 import logging
 import geckodriver_autoinstaller
 
-import srt_deepl.deepl
+import .deepl
 
-from srt_deepl.srt_parser import wrap_line, save_srt
+from .srt_parser import wrap_line, save_srt
 
 # Check if the current version of geckodriver exists
 geckodriver_autoinstaller.install()
